==> lxqt-panel-0.9.0.tar.xz: lxqt-panel-0.9.0/plugin-networkmonitor/translations/networkmonitor_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>LxQtNetworkMonitor</name>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="161"/>
        <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="162"/>
        <source>Transmitted %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="163"/>
        <source>Received %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="208"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>MiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>GiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>TiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>PiB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxQtNetworkMonitorConfiguration</name>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="14"/>
        <source>Network Monitor settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Pagrindinės</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="35"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="56"/>
        <source>Modem</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="65"/>
        <source>Monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="74"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="83"/>
        <source>Wireless</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="95"/>
        <source>Icon</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-panel-0.14.0.tar.xz: lxqt-panel-0.14.0/plugin-networkmonitor/translations/networkmonitor_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>LXQtNetworkMonitor</name>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="161"/>
        <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Tinklo sąsaja &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="162"/>
        <source>Transmitted %1</source>
        <translation>Persiųsta %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="163"/>
        <source>Received %1</source>
        <translation>Gauta %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="208"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="209"/>
        <source>PiB</source>
        <translation>PiB</translation>
    </message>
</context>
<context>
    <name>LXQtNetworkMonitorConfiguration</name>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="14"/>
        <source>Network Monitor settings</source>
        <translation>Tinklo prižiūryklės nustatymai</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Bendra</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="35"/>
        <source>Interface</source>
        <translation>Sąsaja</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="56"/>
        <source>Modem</source>
        <translation>Modemas</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="65"/>
        <source>Monitor</source>
        <translation>Monitorius</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="74"/>
        <source>Network</source>
        <translation>Tinklas</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="83"/>
        <source>Wireless</source>
        <translation>Belaidis</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="95"/>
        <source>Icon</source>
        <translation>Piktograma</translation>
    </message>
</context>
</TS>
